---------------------------------------------------------------------------
License 
Copyright 2004 Grigory (Greg) Nudelman. All Rights Reserved. 
Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met: 

Redistribution of source code must retain this copyright notice, this list of conditions and the following disclaimer.

Redistribution in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution. 

The name of Grigory (Greg) Nudelman may not be used to endorse or promote products derived from this software without specific prior written permission. 

This software is provided "AS IS," without a warranty of any kind. ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY EXCLUDED. THE INVENTOR, Grigory (Greg) Nudelman AND THE LICENSORS OF THIS SOFTWARE SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES. IN NO EVENT WILL THE INVENTOR OR HIS LICENSORS BE LIABLE FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT, INDIRECT, SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF THE INVENTOR HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. 

You acknowledge that this software is not designed, licensed or intended for use in the design, construction, operation or maintenance of any nuclear facility.  
---------------------------------------------------------------------------

package cache;

import java.sql.*;
import java.util.*;

/**
 * Extends the <code>Timestamped</code> interface 
 * with additional methods that allow <code>Cacheable</code>
 * objects to be gracefully loaded from a non-static (object) method
 * of the implementer class. This ensures transparent automatic 
 * Collection (re-)loading by the CacheManager DAO.
 * 
 * @author Greg Nudelman
 * @version 1.0
 */ 
public interface Cacheable extends Timestamped {

    /**
     * Method needed to implement Cacheable interface.
     * For the passed Collection of String ids creates new CD objects and 
     * loads them with all the attributes from the DB.
     * The resulting objects can be cached to be re-used later.
     *
     * NOTE: comes back as unordered as a Collection!!
     * Make sure you sort the final List of cached + db objects BEFORE you return it!
     *
     * @return Collection of fully loaded CD objects from the DB.
     * @author Greg Nudelman
     * @exception ResourceLoadException in case of critical error
     * @version 1.0
     */
    public Collection loadFromIds(Collection idsToRefreshFromDb, Connection conn) throws ResourceLoadException;
}
