---------------------------------------------------------------------------
License 
Copyright 2004 Grigory (Greg) Nudelman. All Rights Reserved. 
Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met: 

Redistribution of source code must retain this copyright notice, this list of conditions and the following disclaimer.

Redistribution in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution. 

The name of Grigory (Greg) Nudelman may not be used to endorse or promote products derived from this software without specific prior written permission. 

This software is provided "AS IS," without a warranty of any kind. ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY EXCLUDED. THE INVENTOR, Grigory (Greg) Nudelman AND THE LICENSORS OF THIS SOFTWARE SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES. IN NO EVENT WILL THE INVENTOR OR HIS LICENSORS BE LIABLE FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT, INDIRECT, SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF THE INVENTOR HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. 

You acknowledge that this software is not designed, licensed or intended for use in the design, construction, operation or maintenance of any nuclear facility.  
---------------------------------------------------------------------------

package cache;

import java.util.*;

/**
 * Timer class that allows the programmer to time many things
 * at once and then print out all the timers for everything
 * in one shot.  
 * 
 * Usage: 
 * instantiate the timer.  
 * call start("methodNameHere")
 * call stop("methodNameHere")
 * you can time as man methods as you like this way 
 * same name of the method overrides older records
 * print everything with a toString() when you are finished
 * if you want, destroy the object by doing timer = null;
 * 
 * @author Greg Nudelman
 * @version PL 2.0
 */
public class Timer {

    long start;
    long stop;
    HashMap timers;

    //CONSTANTS
    private static final String DEFAULT = "DEFAULT";


    //API METHODS
    public Timer() {
        timers = new HashMap();
        //start();
    }

    public Timer(String key) {
        timers = new HashMap();
        start(key);
    }


    public void start() {
        start(DEFAULT);
    }

    public void stop() {
        stop(DEFAULT);
    }

    public void start(String key) {
        if(null == key)
            key = "";
        storeTimeForKey(key, System.currentTimeMillis());
        //System.out.println("STARTING TIMER FOR '" + key + "' >>>");
    }


    public void stop(String key) {
        if(null == key)
            key = "";
        
        long totalTime = System.currentTimeMillis() - getTimeForKey(key);
        
        storeTimeForKey(key, totalTime);
        System.out.println(timeForKey(key));
    }

    public String timeForKey(String key) {
        if(null == key)
            key = "";
        
        return ("---> TIME FOR '" + key + "' " + getTimeForKey(key));
    }


    //TO STRING
    public String toString() {
        if(timers == null)
            return null;

        StringBuffer sb = new StringBuffer();
        Set set = timers.keySet();
        Iterator iterator = set.iterator();

        sb.append("\n\nTimers {\n");
        while(iterator.hasNext()) {            
            String key = (String)iterator.next(); 

            sb.append(timeForKey(key))
                .append("\n");
        }

        sb.append("}\n");

        return sb.toString();
    }


    //PRIVATE HELPERS
    private void storeTimeForKey(String key, long time) {
        timers.put(key, new Long(time));
    }
        
    //returns 0 if key not found -- total will be = System.currentTimeMillis()
    //so watch for huge numbers... you did not quite match start and stop keys
    //but we'll never give you an error.
    private long getTimeForKey(String key) {
        Long startTimeLong = (Long)timers.get(key);
        long startTime = 0;
        if(null != startTimeLong)
            startTime = startTimeLong.longValue();

        return startTime;
    }



    //MAIN FOR TESTING/USAGE EXAMPLE
    public static void main(String[] args) {
          Timer t = new Timer();
          
          System.out.println("debug is on");              

          String abc = "";
          for(int i = 0; i < 1000; i++) {
              abc += "Testing...";
          }

          t.stop();

          System.out.println(t);
      }

}
