---------------------------------------------------------------------------
License 
Copyright 2004 Grigory (Greg) Nudelman. All Rights Reserved. 
Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met: 

Redistribution of source code must retain this copyright notice, this list of conditions and the following disclaimer.

Redistribution in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution. 

The name of Grigory (Greg) Nudelman may not be used to endorse or promote products derived from this software without specific prior written permission. 

This software is provided "AS IS," without a warranty of any kind. ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY EXCLUDED. THE INVENTOR, Grigory (Greg) Nudelman AND THE LICENSORS OF THIS SOFTWARE SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES. IN NO EVENT WILL THE INVENTOR OR HIS LICENSORS BE LIABLE FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT, INDIRECT, SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF THE INVENTOR HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. 

You acknowledge that this software is not designed, licensed or intended for use in the design, construction, operation or maintenance of any nuclear facility.  
---------------------------------------------------------------------------

package cache;

import java.sql.*;
import java.util.*;

/**
 * Simple interface for objects that can be stored in the <code>Cache</code>
 * using the <code>CacheManager</code> API.
 * <code>Timestamp</code> is provided in order to determine object staleness.
 * If the object never expires, just implement this method 
 * to return some constant, like 0 long.
 * <code>Id</code> acts as a key to retrieve the object 
 * in the <code>Cache</code> (<code>Map</code>) interface.  
 * It can be easily changed to <code>Integer</code>, etc. 
 * if the implementation requires it.
 * Any object that implements <code>Timestamped</code> 
 * can be stored in the <code>Cache</code>.
 * However, to (re-)load these objects, java reflection 
 * API must be used. To fully use the power of the 
 * <code>CacheManager</code> API, implement
 * a richer <code>Cacheable</code> interface instead.
 * 
 * @author Greg Nudelman
 * @version 1.0
 */ 
public interface Timestamped {

    public String getId();
    public long getTimestamp();

}
