---------------------------------------------------------------------------
License 
Copyright 2004 Grigory (Greg) Nudelman. All Rights Reserved. 
Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met: 

Redistribution of source code must retain this copyright notice, this list of conditions and the following disclaimer.

Redistribution in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution. 

The name of Grigory (Greg) Nudelman may not be used to endorse or promote products derived from this software without specific prior written permission. 

This software is provided "AS IS," without a warranty of any kind. ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY EXCLUDED. THE INVENTOR, Grigory (Greg) Nudelman AND THE LICENSORS OF THIS SOFTWARE SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES. IN NO EVENT WILL THE INVENTOR OR HIS LICENSORS BE LIABLE FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT, INDIRECT, SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF THE INVENTOR HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. 

You acknowledge that this software is not designed, licensed or intended for use in the design, construction, operation or maintenance of any nuclear facility.  
---------------------------------------------------------------------------

package cache;

/**
 * This class models any unique identifier (id) 
 * with the attached time stamp.
 * Used in the CacheManager API for retriving collections of 
 * cached objects and checking their staleness.
 * This class assumes that the id used in the system is a String.
 * If it's not, please adjust the code accordingly.
 * Note: the objects of this class are immutable.
 *
 * @author  Greg Nudelman
 * @version 1.0
 * @see     CacheManager
 */
public class TimestampedId implements Timestamped, java.io.Serializable {
    private String id;
    private long timestamp;

    public TimestampedId(String id, long timestamp) {
        super();
        init(id, timestamp);
    }

    //private keeps objects immutable (used in constructor only)
    private void init(String id, long timestamp) {
        this.id = id;
        this.timestamp = timestamp;
    }


    public String getId() {
        return this.id;
    }

    public long getTimestamp() {
        return this.timestamp;
    }

    public String toString() {
        return new StringBuffer()
            .append("TimestampedId {")
            .append(id)
            .append(",")
            .append(timestamp)
            .append("}")
            .toString();
    }

}

