---------------------------------------------------------------------------
License 
Copyright 2004 Grigory (Greg) Nudelman. All Rights Reserved. 
Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met: 

Redistribution of source code must retain this copyright notice, this list of conditions and the following disclaimer.

Redistribution in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution. 

The name of Grigory (Greg) Nudelman may not be used to endorse or promote products derived from this software without specific prior written permission. 

This software is provided "AS IS," without a warranty of any kind. ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY EXCLUDED. THE INVENTOR, Grigory (Greg) Nudelman AND THE LICENSORS OF THIS SOFTWARE SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES. IN NO EVENT WILL THE INVENTOR OR HIS LICENSORS BE LIABLE FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT, INDIRECT, SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF THE INVENTOR HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. 

You acknowledge that this software is not designed, licensed or intended for use in the design, construction, operation or maintenance of any nuclear facility.  
---------------------------------------------------------------------------

package cache;

import java.io.*;
import java.util.*;
import java.text.*;

/**
 * All the re-used utilities.
 * @author Greg Nudelman
 * @version 1.0
 */
public final class Util {

    //do not inherit -- do not instantiate
    private Util() {
    }

    /**
     * Decently efficient dump method for HashMap.
     * @author Greg Nudelman
     */
    public static String toString(Map map) {
        if(map == null)
            return null;

        StringBuffer sb = new StringBuffer();
        Set set = map.keySet();
        Iterator iterator = set.iterator();
        Object key = null;

        sb.append("\n\nMap {\n");
        while(iterator.hasNext()) {            
            key = iterator.next(); 
            sb.append("  ")
                .append(key)
                .append("=")
                .append(map.get(key))
                .append("\n");
        }

        sb.append("}\n");

        return sb.toString();
    }



    /**
     * Decently efficient dump method for Collection.
     * @author Greg Nudelman
     */
    public static String toString(Collection col) {
        if(col == null)
            return null;

        StringBuffer sb = new StringBuffer();

        try {
            boolean firstRecord = true;

            Iterator iterator = col.iterator();
            //sb.append("\nCollection {\n");
            while(iterator.hasNext()) {

                if (!firstRecord) {
                    sb.append("\n");
                }

                sb.append(iterator.next());
                firstRecord = false;
            }
        } catch (Exception e) {
            throw new IllegalArgumentException("Util.toString(Collection): exception: " + e);
        }

        //sb.append("\n}\n");
        return sb.toString();
    }



    /**
     * You can pass this method any Collection: 
     * Vector, 
     * PresentationVector,
     * HashMap/HashTable.keySet() 
     * HashMap/HashTable.values()
     * Of Strings
     * 
     * EXAMPLE USE: makeCommaDelimitedIdList(Vector cdIds) 
     * EXAMPLE OUTPUT: "121, 123"
     * This is for making the SQL comma-delimited statements. 
     * WARNING: does not validate the > 254 for the IN SQL.
     * @exception IllegalArgumentException if NPE or class cast exception
     */
    public static String makeCommaDelimitedStringsList(Collection ids) {
        StringBuffer sb = new StringBuffer();

        try {
            Object obj = null;
            boolean firstRecord = true;

            Iterator iterator = ids.iterator();
            while(iterator.hasNext()) {
                obj = iterator.next();

                if (!firstRecord) {
                    sb.append(",");
                }

                String id = (String)obj;
                sb.append("'").append(id).append("'");
                firstRecord = false;
            }
        } catch (Exception e) {
            throw new IllegalArgumentException("Util.makeCommaDelimitedStringsList: exception: " + e);
        }
        return sb.toString();
    }

}
